Retain proteins present in a specified group of a SummarizedExperiment object
filter_overlap.RdFilters the object to retain only proteins that are present (non-NA) in at least one sample within each unique group of the specified condition.
Usage
filter_overlap(object, condition_name)
# S4 method for class 'SummarizedExperiment,character'
filter_overlap(object, condition_name)