Plot Protein Group Counts
plot_pg_counts.RdGenerates a bar plot showing the number of identified protein groups per sample. The plot can either show counts for each individual sample, or show the summarized mean and standard deviation for samples grouped by a condition.
Arguments
- object
A
SummarizedExperimentobject.- condition
Optional. A character string specifying a column name in the
colDataslot. If provided, samples will be grouped by this variable and the plot will show the mean and standard deviation of counts per group. IfNULL(the default), each sample is plotted individually.