Identify Numeric Columns by Index
detect_intensity_cols.RdA helper function that scans a data frame and returns the integer indices of the columns that contain numeric data.
This is primarily used internally by data loading functions to automatically distinguish quantitative intensity columns from metadata columns.