generate_preprocessing_report.Rd
Takes a SummarizedExperiment object with a populated processing_log in its metadata and writes a Markdown file summarizing the preprocessing steps in order.
processing_log
generate_preprocessing_report(object, output_file = "preprocessing_report.md")
A SummarizedExperiment object.
A character string giving the name of the output Markdown file.
Invisibly returns the file path to the Markdown report.