Filter Assay Based on Limit of Detection (LOD)
lod_filter.RdFilters the assay data of a SummarizedExperiment by comparing intensities against a specific Limit of Detection (LOD). The LOD values can be sourced either from a metadata column (rowData) or a specific reference sample (e.g., a Buffer column in the assay).
Usage
lod_filter(se, lod_col = "Buffer")
# S4 method for class 'SummarizedExperiment'
lod_filter(se, lod_col = "Buffer")