Read a Custom Ontology File
read_ontology.RdReads a user-supplied ontology into the TERM2GENE and optional TERM2NAME
structures required by clusterProfiler::enricher() and
clusterProfiler::GSEA().
Supported formats are:
GMT files, where each line is
term,name, then one or more gene IDsDelimited text files (
csvortsv) with either:2 columns:
term,gene3 columns:
term,name,gene
Gene identifiers in uploaded ontologies must match the identifiers used for enrichment. In the ProtPipe Shiny app, this currently means Entrez gene IDs.